@@ -2,12 +2,16 @@
 rconIPM <- function(object, K0,
                      control=object$control, trace=object$trace){
 
+  if (trace>=2)
+    cat("..fitting with rconIPM (C version):\n"); 
 
+  t0 <- proc.time()
   S       <- object$dataRep$S
   nobs    <- object$dataRep$n
   Kstart  <- object$Kstart
-  
-  ctrl <- object$control
+
+
+  ctrl <- control
   logL      = 0
   converged = 1
 
@@ -19,12 +23,12 @@ rconIPM <- function(object, K0,
   vccfit <- control$vccfit
 
   if (vccfit)
-    vcc <- object$intRep$vcc
+    vcc <- object$intRep$vccI
   else
     vcc <- NULL
 
   if (eccfit)
-    ecc <- object$intRep$ecc
+    ecc <- object$intRep$eccI
   else
     ecc <- NULL
 
@@ -33,12 +37,17 @@ rconIPM <- function(object, K0,
   logL0       <- prevlogL <- ellK(K0,S,nobs-1)
   logLeps     <- ctrl$logLeps * abs(logL0)
 
-  Kwork<-.Call("rconipm", S=S, nobs=nobs-1, K0, Glist=glist, 
+  t00 <- proc.time()
+  ##cat("maxouter:", maxouter,"\n")
+  Kwork<-.Call("rconipm", S=S, nobs=nobs-1, K=K0, Glist=glist, 
                maxouter=maxouter, maxinner=maxinner, 
                logL=logL, logLeps=logLeps, deltaeps=deltaeps,
-               converged=converged, trace=0,
-               PACKAGE="gRc")
-
+               converged=converged, debug=trace,
+               PACKAGE="gRc")[[1]]
+  ##Kwork <- ansC[[1]]
+  ##cat("C-call:", proc.time()-t00, "\n")
+  #cat("maxouter:", maxouter, "\n")
+  
   coef <- K2theta(object,Kwork, scale='original')
   vn   <- unlist(lapply(getcc(object),names))
   names(coef) <- vn
@@ -53,7 +62,11 @@ rconIPM <- function(object, K0,
       J <- NULL
     }
   }
+
+  if (trace>=2)
+    cat("..ipm, logL:", logL, "Time:", proc.time()-t0, "\n")
   
+  ##cat("exit rconIPM: Kwork: \n"); print(Kwork)
   ans <- list(K=Kwork, logL=logL, coef=coef, J=J)
   return(ans)
 }
